Stylemee class

Constructors

Stylemee()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

color(String? key, [Color? defaultColor]) Color?
container({List? styles, Widget? child}) StylemeeContainer
extractVariables(String pattern, String text) List<String>
findMatchingStrings(String pattern, List<String> strings) List<String>
init(String file) Future<void>
replaceMapPlaceholders(Map<String, dynamic> inputMap, List<String> variables) Map<String, dynamic>
rule(List? rules, [BuildContext? context]) Map<String, dynamic>
text(String data, {List? styles}) StylemeeText
variable(String? key) String?